$BackgroundTasksInput class abstract

Input for the check and abort background-task tools: a list of task handles.

Annotations
  • @Schema.new()

Constructors

$BackgroundTasksInput()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskIds → List<String>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited