instructions property

  1. @Field.new(description: 'Optional guidance delivered to the sub-agent as it continues. Omit it ' 'to retry a failed or aborted task exactly as it stood; required when ' 'following up on a completed task.')
String? get instructions

Implementation

@Field(
  description:
      'Optional guidance delivered to the sub-agent as it continues. Omit it '
      'to retry a failed or aborted task exactly as it stood; required when '
      'following up on a completed task.',
)
String? get instructions;