$DelegateInput class abstract

Input schema for a generated delegation tool.

Annotations
  • @Schema.new()

Constructors

$DelegateInput()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
task → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited