AsyncContinueInput class base

Input for the continue_task tool when $AgentsOptions.async is set.

Constructors

AsyncContinueInput({required String taskId, String? instructions, bool? background})
AsyncContinueInput.fromJson(Map<String, dynamic> json)
Creates a AsyncContinueInput from a JSON map.
factory

Properties

background ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instructions ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AsyncContinueInput to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<AsyncContinueInput>
The JSON schema and type descriptor for AsyncContinueInput.