BackgroundTaskReport class base

A per-task entry returned by the check and wait background-task tools.

Constructors

BackgroundTaskReport({required String taskId, String? agent, String? name, required String status, String? response, List<AgentDelegationArtifact>? artifacts, String? error})
BackgroundTaskReport.fromJson(Map<String, dynamic> json)
Creates a BackgroundTaskReport from a JSON map.
factory

Properties

agent ↔ String?
getter/setter pair
artifacts ↔ List<AgentDelegationArtifact>?
getter/setter pair
error ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
response ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String
getter/setter pair
taskId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this BackgroundTaskReport to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<BackgroundTaskReport>
The JSON schema and type descriptor for BackgroundTaskReport.