BackgroundTasksInput class base

Input for the check and abort background-task tools: a list of task handles.

Constructors

BackgroundTasksInput({List<String>? taskIds})
BackgroundTasksInput.fromJson(Map<String, dynamic> json)
Creates a BackgroundTasksInput from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskIds ↔ List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this BackgroundTasksInput to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<BackgroundTasksInput>
The JSON schema and type descriptor for BackgroundTasksInput.