BackgroundTasksResult class base

Output for the check and wait background-task tools.

Constructors

BackgroundTasksResult({List<BackgroundTaskReport>? tasks, bool? timedOut, String? note})
BackgroundTasksResult.fromJson(Map<String, dynamic> json)
Creates a BackgroundTasksResult from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
note ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tasks ↔ List<BackgroundTaskReport>?
getter/setter pair
timedOut ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this BackgroundTasksResult to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<BackgroundTasksResult>
The JSON schema and type descriptor for BackgroundTasksResult.