DelegateInput class base

Input schema for a generated delegation tool.

Constructors

DelegateInput({required String task, String? name})
DelegateInput.fromJson(Map<String, dynamic> json)
Creates a DelegateInput from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
task ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this DelegateInput to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<DelegateInput>
The JSON schema and type descriptor for DelegateInput.