$AsyncDelegateInput class abstract

Input schema for a delegation tool when $AgentsOptions.async is set: the plain input plus the background flag.

Annotations
  • @Schema.new()

Constructors

$AsyncDelegateInput()

Properties

background → bool?
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
task → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited