$BackgroundTaskReport class abstract

A per-task entry returned by the check and wait background-task tools.

Annotations
  • @Schema.new()

Constructors

$BackgroundTaskReport()

Properties

agent → String?
no setter
artifacts → List<$AgentDelegationArtifact>?
no setter
error → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String?
no setter
response → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
no setter
taskId → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited