$BackgroundTasksResult class abstract

Output for the check and wait background-task tools.

Annotations
  • @Schema.new()

Constructors

$BackgroundTasksResult()

Properties

hashCode → int
The hash code for this object.
no setterinherited
note → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tasks → List<$BackgroundTaskReport>?
no setter
timedOut → bool?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited