AsyncDelegateInput class base

Input schema for a delegation tool when $AgentsOptions.async is set: the plain input plus the background flag.

Constructors

AsyncDelegateInput({required String task, String? name, bool? background})
AsyncDelegateInput.fromJson(Map<String, dynamic> json)
Creates a AsyncDelegateInput from a JSON map.
factory

Properties

background ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
task ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AsyncDelegateInput to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<AsyncDelegateInput>
The JSON schema and type descriptor for AsyncDelegateInput.