FilesystemPlugin class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init()
→ Future<List<Action>>
-
Called when the plugin is initialized.
inherited
-
list()
→ Future<List<ActionMetadata>>
-
Called to list actions provided by the plugin.
inherited
-
middleware()
→ List<GenerateMiddlewareDef>
-
Middleware provided by the plugin.
-
model(String name)
→ Model
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(String actionType, String name)
→ Action?
-
Called to resolve an action by name.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited