timeoutSeconds property
- @Field.new(description: 'Maximum seconds to wait before returning the current statuses. 0 or ' 'omitted waits until every task settles; a negative value returns the ' 'current statuses immediately.')
Implementation
@Field(
description:
'Maximum seconds to wait before returning the current statuses. 0 or '
'omitted waits until every task settles; a negative value returns the '
'current statuses immediately.',
)
int? get timeoutSeconds;