AgentsOptions class base
Configuration options for the agents middleware.
Constructors
-
AgentsOptions({required List<
String> agents, String? toolPrefix, int? maxDelegations, int? historyLength, String? artifactStrategy}) -
AgentsOptions.fromJson(Map<
String, dynamic> json) -
Creates a AgentsOptions from a JSON map.
factory
Properties
-
agents
↔ List<
String> -
getter/setter pair
- artifactStrategy ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- historyLength ↔ int?
-
getter/setter pair
- maxDelegations ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolPrefix ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this AgentsOptions to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
$schema
→ const SchemanticType<
AgentsOptions> - The JSON schema and type descriptor for AgentsOptions.